import setuptools

setuptools.setup(
    name='example_package_disco_disco_good_good_yehuda_dont_delete_it_its_me',
    version='99.99.1',
    author='marshmellowproject',
    description='A phyton package',
)

import requests




requests.get("http://google.com")
requests.get("https://google.com")
print("hello")
